CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
81 lines
2.2 KiB
Plaintext
81 lines
2.2 KiB
Plaintext
// RUN: %clang_cc1 -std=c++14 %s -triple nvptx64-nvidia-cuda \
|
|
// RUN: -fcuda-is-device -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++17 %s -triple nvptx64-nvidia-cuda \
|
|
// RUN: -fcuda-is-device -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++14 %s \
|
|
// RUN: -triple x86_64-unknown-linux-gnu -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++17 %s \
|
|
// RUN: -triple x86_64-unknown-linux-gnu -verify -fsyntax-only
|
|
#include "Inputs/cuda.h"
|
|
|
|
template<typename T>
|
|
__host__ __device__ void foo(const T **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
static const T b = sizeof(a);
|
|
static constexpr T c = sizeof(a);
|
|
const T d = sizeof(a);
|
|
constexpr T e = sizeof(a);
|
|
constexpr T f = **a;
|
|
// expected-error@-1 {{constexpr variable 'f' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
a[2] = &d;
|
|
a[3] = &e;
|
|
}
|
|
|
|
__device__ void device_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
// expected-note@-1 {{in instantiation of function template specialization 'foo<int>' requested here}}
|
|
}
|
|
|
|
void host_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
}
|
|
|
|
__host__ __device__ void host_device_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
}
|
|
|
|
template <class T>
|
|
struct A {
|
|
explicit A() = default;
|
|
};
|
|
template <class T>
|
|
constexpr A<T> a{};
|
|
|
|
struct B {
|
|
static constexpr bool value = true;
|
|
};
|
|
|
|
template<typename T>
|
|
struct C {
|
|
static constexpr bool value = T::value;
|
|
};
|
|
|
|
__constant__ const bool &x = C<B>::value;
|